@@ -1,35 +1,22 @@
-#ifndef INTRO_SPRITE_H
-#define INTRO_SPRITE_H
 /*
-   This file is part of the KDE games kwin4 program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games kwin4 program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-// Qt includes
+#ifndef INTRO_SPRITE_H
+#define INTRO_SPRITE_H
+
+// own
+#include "thememanager.h"
+#include "pixmapsprite.h"
+// Qt
 #include <QGraphicsPixmapItem>
 #include <QPointF>
 #include <QList>
 #include <QElapsedTimer>
 
-// Local includes
-#include "thememanager.h"
-#include "pixmapsprite.h"
-
 class AnimationCommand;
 
 /** The sprite to display the introduction pieces and their animation.
