@@ -1,33 +1,22 @@
 /*
     This file is part of the KDE games library
-    Copyright (C) 2001 Martin Heni (kde at heni-online.de)
-    Copyright (C) 2001 Andreas Beckermann (b_mann@gmx.de)
+    SPDX-FileCopyrightText: 2001 Martin Heni (kde at heni-online.de)
+    SPDX-FileCopyrightText: 2001 Andreas Beckermann (b_mann@gmx.de)
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef __KGAMEPROPERTYARRAY_H_
 #define __KGAMEPROPERTYARRAY_H_
 
+// own
 #include "kfourinline_debug.h"
-
+// KDEGames
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgame/kgamemessage.h>
 #include <libkdegamesprivate/kgame/kgameproperty.h>
 #include <libkdegamesprivate/kgame/kgamepropertyhandler.h>
-
+// Qt
 #include <QDataStream>
 #include <QVector>
 
