@@ -1,42 +1,27 @@
-#ifndef KWIN4DOC_H
-#define KWIN4DOC_H
 /*
-   This file is part of the KDE games kwin4 program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games kwin4 program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-// Qt Includes
-#include <QList>
-#include <QVector>
+#ifndef KWIN4DOC_H
+#define KWIN4DOC_H
 
-// KDE includes
-#include <KConfig>
-
-#include "kgamepropertyarray.h"
-
-#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
-#include <libkdegamesprivate/kgame/kgame.h>
-#include <libkdegamesprivate/kgame/kgameio.h>
-
-// Local includes
+// own
 #include "kwin4global.h"
 #include "kwin4player.h"
 #include "aiboard.h"
+#include "kgamepropertyarray.h"
+// KDEGames
+#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
+#include <libkdegamesprivate/kgame/kgame.h>
+#include <libkdegamesprivate/kgame/kgameio.h>
+// KF
+#include <KConfig>
+// Qt
+#include <QList>
+#include <QVector>
 
 class KWin4View;
 class Score;
